/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

package org.glite.ce.jobplugin.serialization;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.PrintWriter;
import java.net.Socket;

import org.apache.log4j.Logger;
import org.glite.ce.cream.jobmanagement.util.JobSerialization;
import org.glite.ce.creamapi.jobmanagement.Job;
import org.glite.ce.jobplugin.CREAMJobSensor;

/**
 * Class representing a client of a <code>CREAMJobSensor</code>.
 *
 */
public class CreamJobSensorClientTest {
    /** Logger */
    private static Logger logger = Logger.getLogger(CREAMJobSensor.class.getName());

    final static  String    serverIPname = "localhost";     // server IP name
    final static  int       serverPort   = 49154;           // server port number
    
    /**
     * @param args
     */
    public static void main(String[] args) {
        test();
    }
    
    public static void test() {
        Socket socket = null; // Socket object for communicating
        ObjectInputStream ois = null;
        ObjectOutputStream oos = null;
        PrintWriter pw = null;

        try {
            logger.debug("Client starting ...");
            socket = new Socket(serverIPname, serverPort); // create socket and connect
            logger.debug("got socket ...");

            oos = new ObjectOutputStream(socket.getOutputStream());
            logger.debug("Connected to Server");

            //Job job1 = JobSerialization.getDummyJob();
            //logger.debug("Before serialization 1");
            
            for (int i = 0; i < 5; i++) {
                Job job = JobSerialization.getDummyJob();
                job.setId(Integer.toString(i));
                job.writeExternal(oos);
                oos.flush();
                logger.debug(Thread.currentThread().getName() + " sent JOB" + i);
                Thread.currentThread().sleep(2000);
            }
            Thread.currentThread().sleep((long) (Math.random()*1000));
            logger.debug(Thread.currentThread().getName() + " is going to die");
            
            oos.close();
            socket.close();

        } catch (Throwable e) {
            System.out.println("Error " + e.getMessage());
            e.printStackTrace();

        }
    }
    

}
